# Methods

```{toctree}
:maxdepth: 1

methods/mahalanobis.ipynb
methods/iforest.ipynb
methods/vae.ipynb
methods/ae.ipynb
methods/vaegmm.ipynb
methods/aegmm.ipynb
methods/llr.ipynb
methods/prophet.ipynb
methods/sr.ipynb
methods/seq2seq.ipynb
```
